#
# spec file for package babl
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define debug_package_requires libbabl-0_1-0 = %{version}-%{release}

Name:           babl
Version:        0.1.110
Release:        1.3
Summary:        Dynamic Pixel Format Translation Library
License:        GPL-3.0-or-later AND LGPL-3.0-or-later
Group:          Development/Libraries/C and C++
URL:            https://gegl.org/babl/
Source0:        https://download.gimp.org/pub/babl/0.1/%{name}-%{version}.tar.xz
Source99:       baselibs.conf
BuildRequires:  meson >= 0.54.0
BuildRequires:  pkgconfig
BuildRequires:  vala
BuildRequires:  pkgconfig(gobject-introspection-1.0)
BuildRequires:  pkgconfig(lcms2)
# None of these is needed for standard build:
#BuildRequires:  inkscape ruby w3m
%{?suse_build_hwcaps_libs}

%description
babl is a dynamic, any to any, pixel format translation library.

%package -n libbabl-0_1-0
Summary:        Dynamic Pixel Format Translation Library
Group:          System/Libraries

%description -n libbabl-0_1-0
babl is a dynamic, any to any, pixel format translation library.

It allows converting between different methods of storing pixels known
as pixel formats that have with different bitdepths and other data
representations, color models and component permutations.

A vocabulary to formulate new pixel formats from existing primitives is
provided as well as the framework to add new color models and data
types.

%package -n typelib-1_0-Babl-0_1
Summary:        Introspection bindings for babl
Group:          System/Libraries

%description -n typelib-1_0-Babl-0_1
babl is a dynamic, any to any, pixel format translation library.

This package provides the GObject Introspection bindings for babl.

%package devel
Summary:        Dynamic Pixel Format Translation Library
Group:          Development/Libraries/C and C++
Requires:       glibc-devel
Requires:       libbabl-0_1-0 = %{version}
Requires:       typelib-1_0-Babl-0_1 = %{version}

%description devel
babl is a dynamic, any to any, pixel format translation library.

%prep
%autosetup -p1

%build
%meson \
  -Dgi-docgen=disabled \
	%{nil}
%meson_build

%install
%meson_install

%post -n libbabl-0_1-0 -p /sbin/ldconfig
%postun -n libbabl-0_1-0 -p /sbin/ldconfig

%files -n libbabl-0_1-0
%license COPYING
%doc NEWS
%{_libdir}/*.so.*
%{_libdir}/babl-0.1/

%files -n typelib-1_0-Babl-0_1
%{_libdir}/girepository-1.0/Babl-0.1.typelib

%files devel
%doc AUTHORS TODO
%{_includedir}/babl-0.1/
%{_bindir}/babl
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc
%{_datadir}/gir-1.0/Babl-0.1.gir
%dir %{_datadir}/vala/vapi
%{_datadir}/vala/vapi/babl-0.1.deps
%{_datadir}/vala/vapi/babl-0.1.vapi

%changelog
* Wed Nov  6 2024 Marcus Rueckert <mrueckert@suse.de>
- Update to 0.1.110:
  - Build improvements.
  - Fixes to alpha componet in HCY, HSL, HSV and YCbCr models.
  - Use same CIE Lab conversion for start/end as rest with SIMD.
  - Remove reliance on set rounding mode.
* Thu Feb 22 2024 Marcus Rueckert <mrueckert@suse.de>
- disable gi-docgen docs for now
* Thu Feb 22 2024 Marcus Rueckert <mrueckert@suse.de>
- Update to 0.1.108:
  - "double" and "half" support in cli-tool, build fixes.
* Thu May 18 2023 Paolo Stivanin <info@paolostivanin.com>
- Update to 0.1.106:
  * Disable LUTs on big-endian, fix to 1bpp->4bpp LUTs, faster startup by caching
    balanced RGB to XYZ matrices.
  * LUT code-paths re-enabled, some array overflow proofing.
* Thu Mar  9 2023 Paolo Stivanin <info@paolostivanin.com>
- Build AVX2 enabled hwcaps library for x86_64-v3
* Wed Mar  1 2023 Paolo Stivanin <info@paolostivanin.com>
- update to 0.1.102:
  * LUT code-paths now disabled by default.
  * Stop double processing with LUT+normal fishes.
  * Support for non-ASCII characters in file paths on windows.
    Improved wrap build support.
* Tue Nov 22 2022 Petr Vorel <pvorel@suse.cz>
- update to 0.1.98:
  * More robust bounds protection in ICC handling, avoid garbage collecting
    lookup tables in-line with processing.
* Mon Aug 29 2022 Dirk Müller <dmueller@suse.com>
- update to 0.1.96:
  * Minor changes from 0.1.94, fixing build.
  * Fix of crash on non-aligned data for SIMD, add commandline tool, improve vala
    compatibility of introspection info.
- drop patches 2dc7fc40.patch, b05b2826.patch (upstream)
* Tue May  3 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Add patches, backported from git, to fix build with meson 0.62:
  + 2dc7fc40.patch
  + b05b2826.patch
* Sat Apr  9 2022 Dirk Müller <dmueller@suse.com>
- update to 0.1.92:
  * Fixes for avoiding load of wrong SIMD extensions
* Tue Mar  1 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to version 0.1.90:
  * Automatic LUT creation for conversions from &lt;24bpp of colorant
    componants, SIMD builds for x86_64 micro-architecture levels and
    ARM neon, pre-defined CIE Lab u8 and CIE Lab u16 formats.
  * Fix bug of an unlocked non-locked mutex, which started failing
    on some platforms.
* Tue Jul 13 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 0.1.88:
  + Consistency fixes to format names, in particular for palettized
    formats.
* Tue Mar 16 2021 Dirk Müller <dmueller@suse.com>
- update to 0.1.86:
  * input-class (scanner/RGB) ICC profiles are valid for creating RGB spaces.
  * improved thread safety for babl_space_from_icc
  * build: allow using babl a subproject in other meson projects.
* Mon Dec 28 2020 Wang Jun <jgwang@suse.com>
- Update to version 0.1.84:
  * Fixed bug in caching of CMYK ICC profiles.
* Thu Oct  8 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.1.82:
  + Handle the parametric ICCv4 types that are not strictly the
    same type as core sRGB curve.
  + Meson build cleanups, depend on meson 0.54.
* Mon Aug 10 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.1.80:
  + No upstream changes provided.
* Thu Jun 11 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to version 0.1.78:
  * Bugfix release - mutex and atomicity related issues.
  * Wrap hue in HSV, HSL, HCY. Fix black pullout in non ICC CMYK
    conversion. Added AV2 gamme u8->linear float conversions.
    VAPI file generation for vala integration. Adjusted strategy
    for conversion selection, trades back warm-up time for missing
    some fast multi-step conversions.
* Tue Feb  4 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.1.74:
  + Build fixes, improved host cpu detection, OSX fixes, clang
    warning squelches.
* Fri Aug 23 2019 Jan Engelhardt <jengelh@inai.de>
- Trim package descriptions on packages installed more rarely.
* Fri Aug 23 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.1.72:
  + Added handling for grayscale ICC profiles and gobject
    introspection support.
  + Optimizations for many format conversions for u8, u16 and half
    formats.
  + Fixed a crash for NANs in float to u8 conversions.
- Drop babl-add-sse2_cflags-to-CIE.patch: Fixed upstream.
- Add pkgconfig(gobject-introspection-1.0) BuildRequires: New
  dependency.
- Following the above, package new sub-package
  typelib-1_0-Babl-0_1.
* Sun Aug  4 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.1.70:
  + Build fixes making the meson build work with more
    architectures.
- Changes from version 0.1.68:
  + Added Yu'v' (CIE 1976 UCS) color model.
  + Fixed a severe non-initialised memory issue - that kept us from
    using fast paths for many babl spaces loaded from profile.
  + More fully symmetric conversions between associated and
    separate alpha.
  + Added more converters, both SSE2 and non-SSE2 for
    matrix-conversion between different RGB spaces.
  + Improvements to website/documentation; babl is now using the
    terms associated alpha and separate alpha, all of:
    nonpremultiplied-, premultiplied- and nonassociated- alpha are
    now considered deprecated API.
  + HCY luminance is now relative to the RGB space used - no change
    for sRGB related pixel formats. AVX2 acceleration for some
    linear to float conversions.
- Add meson BuildRequires and macros, upstream switched to meson
  only.
- Add pkgconfig(lcms2) BuildRequires: New dependency.
- Add babl-add-sse2_cflags-to-CIE.patch: Fix build for i586
  (glgo#GNOME/babl!42, glgo#GNOME/babl#23).
* Sat Jun 15 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.1.66:
  + Added API call, babl_space_get_rgb_luminance.
  + Make most SIMD code-paths optional again on i686.
* Sun May 26 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.1.64:
  + Support for Hygon Dhyana, and Y~aA formats for symmetric
    completeness.
  + Code consistency, gitlab CI, autotools and meson build
    improvements.
* Wed Mar 20 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.1.62:
  + Initial CMYK spaces with lcms2 based ICC support, much room for
    optimization.
  + Improved custom space support for palette formats.
  + scRGB space, works like sRGB but always with linear TRCs.
  + Model introspection API permitting low overhead checks whether
    a format/model is RGB, CMYK type of alpha and similar.
* Tue Dec  4 2018 bjorn.lie@gmail.com
- Update to version 0.1.60:
  + Improved thread safety, acceleration for R'G'B'A u8 ->
    cairo-ARGB32 conversion.
* Wed Oct 24 2018 sean@suspend.net
- Update to version 0.1.58:
  + Preserve color of transparent pixels in conversion to
    premultiplied alpha.
  + Added single precision code-paths for faster fallback/reference
    conversions.
  + New BABL_ICC_INTENT_PERFORMANCE bitflag for combing with intent
    as bitflags.
* Thu Aug 30 2018 Ismail Dönmez <idonmez@suse.com>
- Update license to LGPL-3.0-or-later AND GPL-3.0-or-later per the
  feedback from legal.
* Thu Aug 23 2018 bjorn.lie@gmail.com
- Update to version 0.1.56:
  + Improvements to the caching of profiled conversion chains
    between invocations by ignoring unknown bits in cache file and
    remember which conversions yielded reference fishes.
- Changes from version 0.1.54:
  + Export babl_space_get_icc, babl_space_get,
    babl_model_with_space, babl_space_with_trc,
    babl_format_get_encoding, babl_model_is, SSE2 versions of YA
    float and Y float to CIE L float.
* Thu Jul  5 2018 bjorn.lie@gmail.com
- Update to version 0.1.52:
  + Concurrency fixes and fixes to handling of 0/1 entry palettes.
  + Do not pre-equalize XYZ conversion matrices for sRGB.
  + Internal clean-ups.
  + Pre-define ACES2065-1 and ACEScg BablSpaces.
  + Add R~G~B~ set of spaces, which for all BablSpaces mean use
    sRGB TRC.
* Mon May 21 2018 plinnell@opensuse.org
- Update to version 0.1.50:
  + Improvements to speed and precision of indexed code.
  + Improvements to mesonbuild.
* Wed May 16 2018 bjorn.lie@gmail.com
- Update to version 0.1.48:
  + Fix u8 <-> double conversions for chroma, SSE2 version of RGBA
    float to CIE L / Lab.
  + Build with -Ofast by default.
* Tue May  8 2018 bjorn.lie@gmail.com
- Add baselibs.conf, build 32-bit support.
* Wed Apr 18 2018 bjorn.lie@gmail.com
- Update to version 0.1.46:
  + Added extensions with more coverage for u32, half and other
    utilit fast paths.
  + Improving fast path coverage.
* Wed Mar  7 2018 bjorn.lie@gmail.com
- Update to version 0.1.44:
  + Fix bug in custom primaries/ICC fast paths, improve meson
    build.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Fri Jan 26 2018 bjorn.lie@gmail.com
- Update to version 0.1.42:
  + Fully initialize fishes when loading from cache.
* Mon Jan 22 2018 luc14n0@linuxmail.org
- Update to version 0.1.40:
  + Added:
  - Format "CIE XYZ alpha" color model and formats;
  - Meson build; being tested in parallel with automake.
  + New API babl_process_rows for reduced overhead in some
    scenarios; though bigger gains seen also for regular
    babl_process with reimplemented branch-free dispatch, and
    faster cbrt.
  + Improved reference conversions for formats skipping some of
    models components.
  + Fixed gamma handling in indexed/palettized formats and improved
    gamma precision consistenct in sse2 conversions.
* Sun Dec 31 2017 jengelh@inai.de
- Fix RPM groups. Drop comment about author extraction (not used
  for specfiles in general anymore).
* Thu Dec 28 2017 zaitor@opensuse.org
- Update to version 0.1.38:
  + Added format "CIE L float", a couple of protections against
    division by 0.0.
- Changes from version 0.1.36:
  + Optimized customized primary aware code paths for CIE
    Lab<->RGB conversions, improved accuracy of gamma
    approximations.
  + New API babl_format_exists() for checking validity of babl
    format name, crash proofing of cache handling and use of
    environment variables.
* Sun Nov  5 2017 luc14n0@linuxmail.org
- Update to version 0.1.34:
  + Brown paper bag release
  + Fix indexed / custom primaries conflict
  + Re-export a symbol used by old GEGL/GIMPs
- Changes from version 0.1.32:
  + Added custom primaries and TRC support through ICC parsing
  + Improved float<->half performance
  + Rewrite of all conversions functions to adhere to new signature
* Thu Aug 24 2017 zaitor@opensuse.org
- Update to version 0.1.30:
  + Thread stability for palette modes, stricter alpha
    preservation, now cross-compilable on android.
* Tue Jul  4 2017 zaitor@opensuse.org
- Update to version 0.1.28:
  + Fast paths for Lav <-> Lch, release triggered by pending GIMP
    release.
* Thu May 18 2017 zaitor@opensuse.org
- Update to version 0.1.26:
  + Build and install HCY color space, platform independences fixes
    to fish cache.
* Sun Feb  5 2017 zaitor@opensuse.org
- Update to version 0.1.24:
  + Improvements to profile cache persistance, fast paths that
    improve actual GIMP use on various precisions, use single
    precision constants for some more of CIE computions.
* Wed Jan 11 2017 zaitor@opensuse.org
- Update to version 0.1.22:
  + Added cache of profiled conversions, added HCY color model,
    some precision and performance updated for fast paths.
- Changes from version 0.1.20:
  + Fix run-time errors, leaks, and race conditions. Add
    conditional fast paths.
* Tue Jun 21 2016 zaitor@opensuse.org
- Update to version 0.1.18:
  + Bugfix: take alpha threshold in consideration when processing
    floats in SSE2.
* Fri Apr 15 2016 mgorse@suse.com
- Update to GNOME 3.20  Fate#318572
* Fri Mar 11 2016 zaitor@opensuse.org
- Update to version 0.1.16:
  + Improvements to half float reference, SIMD, and fast-paths, and
    CIE float fast paths; cleanups of fast path extensions.
* Thu Nov 26 2015 zaitor@opensuse.org
- Update to version 0.1.14:
  + sRGB precision tuning
  + Stability fixes
  + Locale fix for setting error tolerance.
* Wed Feb 11 2015 zaitor@opensuse.org
- Drop vala, libtool and gobject-introspection-devel BuildRequires,
  they are no longer needed.
- Due to above changes, no longer define build_vala, stop passing
  autogen.sh to configure, nor --enable-introspection or
  - -without-vala.
- Drop typelib-1_0-Babl-0_1 Requires from devel package, it no
  longer exists.
* Sat Feb  7 2015 sfalken@opensuse.org
- Update to version 0.1.12:
  + optimizations for floating point conversions, HSV and HSL
    color models
  + removal of dead code
  + fixed CIE Lab conversions
- Patches Dropped:
  + babl-fix-gir-build.patch
  + babl-fix-gir.patch
  + Modified .spec to remove typelib package and gir-related %%files
  entries.  Package no longer provides them.
* Tue Apr  3 2012 vuntz@opensuse.org
- Update to version 0.1.10:
  + LUT based speedups for gamma correction / uncorrection.
- Changes from version 0.1.8:
  + Added support for indexed/pallette based formats.
  + Constified API.
- Pass --enable-introspection to configure to make sure we build
  introspection support.
- Add babl-fix-gir-build.patch: this fixes the build of
  introspection (as well as the generated data).
- Since the build of vala bindings is broken, temporarily disable
  it with a build_vala macro that helps us pass --without-vala to
  configure.
* Tue Jan 10 2012 dimstar@opensuse.org
- Add babl-fix-gir.patch: Fix building of the .gir and .typelib
  files.
- Add vala and gobject-introspection BuildRequires to build the
  introspection and vala support.
- Create typelib-1_0-Babl-0_1 subpackage for typelib.
- Add typelib-1_0-Babl-0_1 Requires to -devel package.
- Add libtool BuildRequires and call to autogen.sh as the patch
  babl-fix-gir.patch touches the build system.
* Sun Nov 20 2011 dimstar@opensuse.org
- Update to version 0.1.6:
  + Build improvements
  + Remove blatantly wrong conversions from extensions
  + Made it possible to distinguish format_n formats from others
  + Improvements to vala/gobject introspection support.
* Sat Sep 17 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
- Use %%_smp_mflags for parallel build
* Sat Apr 16 2011 mrdocs@opensuse.org
- Update to version 0.1.4:
  + many build and autotool fixes
  + Add experimental introspection support - disabled by default
  + Add code to handle N-components.
* Mon May  3 2010 coolo@novell.com
- buildrequire pkg-config to fix provides
* Fri Jan 15 2010 vuntz@opensuse.org
- Update to version 0.1.2:
  + Made babl mostly threadsafe (sufficient for GIMP/GEGLs needs).
  + Streamlined core functionality, reducing number of function
    calls and removing overeager instrumentation.
- Drop babl-fix-install.patch: fixed upstream. The autoreconf call
  can also be removed.
- Rename libbabl-0_0-0 to libbabl-0_1-0, following soname change.
  This also means we can remove the Provides/Obsoletes for
  babl-0_0.
* Fri May 22 2009 vuntz@novell.com
- Update to version 0.1.0:
  + Support for RGBA representation in the frequency domain
  + Un-pre-multiply close-to-zero alpha values to complete black
    instead of slightly brighter than black
  + Add a BABL_ALPHA_THRESHOLD constantto the API
  + Do a complete overhaul of the babl API
  + Do some changes to increase portability of the library.
- Drop babl-undefined.patch: fixed upstream.
- Add babl-fix-install.patch to fix the build.
- Remove babl-0_0 package and make libbabl-0_0-0 provide/obsolete
  it.
- COPYING.lesser doesn't exist anymore. The package is LGPLv3+
  only (no more GPL).
* Mon Dec 15 2008 sbrabec@suse.cz
- Fixed undefined operation (bnc#449633).
* Wed Oct 22 2008 maw@suse.de
- Make debug packages require a specific %%{version}-%%{release}.
* Mon Sep  8 2008 dmueller@suse.de
- fix build
* Mon Jul 21 2008 sbrabec@suse.cz
- New SuSE package.
